// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetSupportLib = {
	$DOTNET: {
		conv_string: function (mono_obj) {
			return MONO.string_decoder.copy (mono_obj);
		}
	},
	mono_wasm_invoke_js_blazor: function(exceptionMessage, callInfo, arg0, arg1, arg2)	{
		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			var blazorExports = globalThis.Blazor;
			if (!blazorExports) {
				throw new Error('The blazor.webassembly.js library is not loaded.');
			}

			return blazorExports._internal.invokeJSFromDotNet(callInfo, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_marshalled: function(exceptionMessage, asyncHandleLongPtr, functionName, argsJson, treatResultAsVoid) {

		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			// Passing a .NET long into JS via Emscripten is tricky. The method here is to pass
			// as pointer to the long, then combine two reads from the HEAPU32 array.
			// Even though JS numbers can't represent the full range of a .NET long, it's OK
			// because we'll never exceed Number.MAX_SAFE_INTEGER (2^53 - 1) in this case.
			//var u32Index = $1 >> 2;
			var u32Index = asyncHandleLongPtr >> 2;
			var asyncHandleJsNumber = Module.HEAPU32[u32Index + 1]*4294967296 + Module.HEAPU32[u32Index];

			// var funcNameJsString = UTF8ToString (functionName);
			// var argsJsonJsString = argsJson && UTF8ToString (argsJson);
			var funcNameJsString = DOTNET.conv_string(functionName);
			var argsJsonJsString = argsJson && DOTNET.conv_string (argsJson);

			var dotNetExports = globaThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}

			if (asyncHandleJsNumber) {
				dotNetExports.jsCallDispatcher.beginInvokeJSFromDotNet(asyncHandleJsNumber, funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return 0;
			} else {
				var resultJson = dotNetExports.jsCallDispatcher.invokeJSFromDotNet(funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return resultJson === null ? 0 : mono_string(resultJson);
			}
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_unmarshalled: function(exceptionMessage, funcName, arg0, arg1, arg2)	{
		try {
			// Get the function you're trying to invoke
			var funcNameJsString = DOTNET.conv_string(funcName);
			var dotNetExports = globalThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}
			var funcInstance = dotNetExports.jsCallDispatcher.findJSFunction(funcNameJsString);

			return funcInstance.call(null, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var mono_string = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']); // TODO: Cache
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	}


};

autoAddDeps(DotNetSupportLib, '$DOTNET')
mergeInto(LibraryManager.library, DotNetSupportLib)


// SIG // Begin signature block
// SIG // MIIomgYJKoZIhvcNAQcCoIIoizCCKIcCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // DQxM5aUosMIFmI353dLRcro0jWTAvinWkY5FLkoNZqCg
// SIG // gg3wMIIGbjCCBFagAwIBAgITMwAAAwVNYg1ohQeqMwAA
// SIG // AAADBTANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIyMDgwNDIwMjM1N1oX
// SIG // DTIzMDgwMzIwMjM1N1owYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBALgT1J98uPoa1weiQsnOFH3y
// SIG // L9VcrQ5JLGIZT50ZFJp4cOpQ+gHtRxxVE89hPiTPzLAR
// SIG // VHaubXNodZsBmWk4PbWNkPwm0aKis02uN71Farp9Ouc5
// SIG // 0Pzn1DT+R3+e3ahXLhtC5mlTaCZiJ4AU3blyaqQLKLeJ
// SIG // a3pqyHBnJiXySNBrhLBkleguDLiqBLaziCWbQLAIlLUl
// SIG // ypI/cutECrDKU4/f7PHM+1gUQdK+WZnH/+t82oAY0VXG
// SIG // 3pUMZzv3UysNO4CS1aFAjQG5cjdJuS812n658mOSIPwF
// SIG // 5zmfaIH14qh/XPyfi0a6WdZaZIRth3dnP9VcGN1sDSuc
// SIG // RV/no9+aSPqWyt19ipN4jiuJILUHhm+3eekt2KGaKWys
// SIG // 2whswE1RkBoAq7GmvFIrXvcEB0mqM/09bIfgvkjN50z/
// SIG // 5XmMlyrqtmD0Fe+V1DTbfOyhdBZpt4G2cbqK3eoFUoJI
// SIG // ytn3N06zIBT0kd8BVWDWKOTi0VHsXx8cvHDKDLOL5iK2
// SIG // REcibwIDAQABo4IBfjCCAXowHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFMPGGeTy
// SIG // z3Y+F0AQcJOKcmziq1YbMFAGA1UdEQRJMEekRTBDMSkw
// SIG // JwYDVQQLEyBNaWNyb3NvZnQgT3BlcmF0aW9ucyBQdWVy
// SIG // dG8gUmljbzEWMBQGA1UEBRMNNDY0MjIzKzQ3MjIzNzAf
// SIG // BgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBU
// SIG // BgNVHR8ETTBLMEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jv
// SIG // c29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUw
// SIG // UzBRBggrBgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3Nv
// SIG // ZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAw
// SIG // DQYJKoZIhvcNAQEMBQADggIBAGhKSnmsyGvycL6Dw4uq
// SIG // 3wDtwdM/hSbG6b5NqxUtIoE9TMT4Uqj+NWtYfrB09uq8
// SIG // OzxkLHnaEec19x5EyVxy+DBpbmzNU3/469qF4kyp0FNj
// SIG // CJlmFgFoxLNFzisxKeTXw1pFppM5AxHG+/VqIdQlOCbc
// SIG // 2nTSJLqxag4G3J+fsEE6uywxw6NxfieRBzAJd2HGPLUV
// SIG // pt87GLklNjsyxDUJYkxFtgkj1khGqwIG6ZNkbIXPsxR8
// SIG // S9oiKqAP71cZEwN6+TnnPIotqXeBsC+urL/NB8NWxBEe
// SIG // npVFFF4zNXd3sbmb4H/668DKQaIP5Qm0Ige2nmxgXAPq
// SIG // 9CPYZawXOvxOhOFgiU3AtLFAK/Oc+sgkXCeLX2A6RKq8
// SIG // SqgwHwtjWXaviyEToDFwSMdel+y+9wSZokXBwr+7TjGL
// SIG // uRinndUGjiVtJU/rsz/y9xC5TiOn6BAjwXB0EktoM0dP
// SIG // cTu3d9AC0q2gylEwTPAdfSbpABG+IPHEgtOoDxSBxUGc
// SIG // hdEElyklcwz6C8oGSXR6CVGHV7QW+cH03C9DH7nBBhAh
// SIG // UIojqCYwKb9b8Gam25brrUFwf8to5dXLZ14HYeRA9c6A
// SIG // H2CBwiE4ABPpOq/iypGWil8Vyg3Uf6LmgAEMMxZYLtNg
// SIG // 5GbM3tcTW2M3C0EZFIpiuT43hvm8uNHpXAZP3PJ3yCc5
// SIG // yR09MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkq
// SIG // hkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEy
// SIG // MDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNh
// SIG // dGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5
// SIG // WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWdu
// SIG // aW5nIFBDQSAyMDExMIICIjANBgkqhkiG9w0BAQEFAAOC
// SIG // Ag8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGf
// SIG // Qhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDI
// SIG // OdUBFDFC04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv
// SIG // 2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13Y
// SIG // xC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT
// SIG // +OPeBw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy
// SIG // 4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
// SIG // kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
// SIG // OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVf
// SIG // GCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmdX4ji
// SIG // JV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bys
// SIG // AoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLn
// SIG // JN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zdsGbiwZeB
// SIG // e+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx
// SIG // 7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwT
// SIG // XWCVmj5PM4TasIgX3p5O9JawvEagbJjS4NaIjAsCAwEA
// SIG // AaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1Ud
// SIG // DgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEE
// SIG // AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYw
// SIG // DwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToC
// SIG // MZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBL
// SIG // hklodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
// SIG // bC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
// SIG // MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
// SIG // BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNf
// SIG // MjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcu
// SIG // AzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1hcnljcHMu
// SIG // aHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABf
// SIG // AHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQA
// SIG // LiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn8oalmOBUeRou
// SIG // 09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+
// SIG // vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzS
// SIG // Gksc8zxCi1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlE
// SIG // PXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6V
// SIG // oCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu
// SIG // 5a8n7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560
// SIG // STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
// SIG // mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
// SIG // bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HN
// SIG // pZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYbBL7f
// SIG // QccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AA
// SIG // KcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3
// SIG // S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sLgOppO6/8
// SIG // MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7
// SIG // qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJ
// SIG // UnMTDXpQzTGCGgIwghn+AgEBMIGVMH4xCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2Rl
// SIG // IFNpZ25pbmcgUENBIDIwMTECEzMAAAMFTWINaIUHqjMA
// SIG // AAAAAwUwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcN
// SIG // AQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
// SIG // MAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIPei
// SIG // aMpT7aW0G0eaO4V7u+OYsUIWBD2V6EuD1ajffj24MEIG
// SIG // CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBv
// SIG // AGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20w
// SIG // DQYJKoZIhvcNAQEBBQAEggGAAOiMMlUcSVcZG2sRtROK
// SIG // yoM/PzvvdfB35yy25cGv+Q66BPzfzEz3jgAyJm/cNvJx
// SIG // tsbEzrxNCH+r58Jl0BaDtzTRb6w39J01/GHFH5hB78+x
// SIG // 5KwkhrOdr6JKG4Y9TQmvM+PPII5yvhh5F2XyDKYarYvt
// SIG // 6IO2B3ZvXNWsXzprWQyFztoO9T9QZilzSlsvsgHdQrem
// SIG // d/xMA98I6ZMxeF4xbynTflus5eG56BlwXC4OVO7hlY3l
// SIG // SsXurppMt5vt/Dc0VKfIrXhBg9ZZQr5tFgUedTVmv3PJ
// SIG // jB7F26+1rxIxBHzlWOq+2Y5LhJucMJPalZyXEr7FoG9v
// SIG // we3k/ENqf+qpejR6uNTHNnfkuQWCJz/2qHLFY1rfmDFd
// SIG // svYVNKARdAtztRCtonnvqqSbvAMe1B0FM0MMRD34kABZ
// SIG // qNM104jKu9jAuaxhlgyXryXE1FWDGKUjl8266C09luRJ
// SIG // hAM1ng9dzXQu2rt4jda3PuxmGfIIcfxRUtchwjReKd8/
// SIG // cpjO1hREoYIXDDCCFwgGCisGAQQBgjcDAwExghb4MIIW
// SIG // 9AYJKoZIhvcNAQcCoIIW5TCCFuECAQMxDzANBglghkgB
// SIG // ZQMEAgEFADCCAVUGCyqGSIb3DQEJEAEEoIIBRASCAUAw
// SIG // ggE8AgEBBgorBgEEAYRZCgMBMDEwDQYJYIZIAWUDBAIB
// SIG // BQAEIG1Cdg6B8ylQKiD7Cu56Uz3qGpTfoHq1O4aKaUq9
// SIG // UeSrAgZjc9I/IeEYEzIwMjIxMTI5MDU0MjU1LjA2M1ow
// SIG // BIACAfSggdSkgdEwgc4xCzAJBgNVBAYTAlVTMRMwEQYD
// SIG // VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
// SIG // MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
// SIG // KTAnBgNVBAsTIE1pY3Jvc29mdCBPcGVyYXRpb25zIFB1
// SIG // ZXJ0byBSaWNvMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVT
// SIG // Tjo4OTdBLUUzNTYtMTcwMTElMCMGA1UEAxMcTWljcm9z
// SIG // b2Z0IFRpbWUtU3RhbXAgU2VydmljZaCCEV8wggcQMIIE
// SIG // +KADAgECAhMzAAABqwkJ76tj1OipAAEAAAGrMA0GCSqG
// SIG // SIb3DQEBCwUAMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
// SIG // EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
// SIG // HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAk
// SIG // BgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAy
// SIG // MDEwMB4XDTIyMDMwMjE4NTEyOFoXDTIzMDUxMTE4NTEy
// SIG // OFowgc4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
// SIG // aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
// SIG // ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKTAnBgNVBAsT
// SIG // IE1pY3Jvc29mdCBPcGVyYXRpb25zIFB1ZXJ0byBSaWNv
// SIG // MSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVTTjo4OTdBLUUz
// SIG // NTYtMTcwMTElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUt
// SIG // U3RhbXAgU2VydmljZTCCAiIwDQYJKoZIhvcNAQEBBQAD
// SIG // ggIPADCCAgoCggIBAMmdS1o5dehASUsscLqyx2wm/Wir
// SIG // NUfqkGBymDItYzEnoKtkhrd7wNsJs4g+BuM3uBX81WnO
// SIG // 270lkrC0e1mmDqQt420Tmb8lwsjQKM6mEaNQIfXDronr
// SIG // VN3aw1lx9bAf7VZEA3kHFql6YAO3kjQ6PftA4iVHX3JV
// SIG // v98ntjkbtqzKeJMaNWd8dBaAD3RCliMoajTDGbyYNKTv
// SIG // xBhWILyJ8WYdJ/NBDpqPzQl+pxm6ZZVSeBQAIOubZjU0
// SIG // vfpECxHC5vI1ErrqapG+0oBhhON+gllVklPAWZv2iv0m
// SIG // gjCTj7YNKX7yL2x2TvrvHVq5GPNa5fNbpy39t5cviiYq
// SIG // Mf1RZVZccdr+2vApk5ib5a4O8SiAgPSUwYGoOwbZG1on
// SIG // Hij0ATPLkgKUfgaPzFfd5JZSbRl2Xg347/LjWQLR+KjA
// SIG // yACFb06bqWzvHtQJTND8Y0j5Y2SBnSCqV2zNHSVts4+a
// SIG // UfkUhsKS+GAXS3j5XUgYA7SMNog76Nnss5l01nEX7sHD
// SIG // dYykYhzuQKFrT70XVTZeX25tSBfy3VaczYd1JSI/9wOG
// SIG // qbFU52NyrlsA1qimxOhsuds7Pxo+jO3RjV/kC+AEOoVa
// SIG // XDdminsc3PtlBCVh/sgYno9AUymblSRmee1gwlnlZJ0u
// SIG // iHKI9q2HFgZWM10yPG5gVt0prXnJFi1Wxmmg+BH/AgMB
// SIG // AAGjggE2MIIBMjAdBgNVHQ4EFgQUFFvO8o1eNcSCIQZM
// SIG // vqGfdNL+pqowHwYDVR0jBBgwFoAUn6cVXQBeYl2D9OXS
// SIG // ZacbUzUZ6XIwXwYDVR0fBFgwVjBUoFKgUIZOaHR0cDov
// SIG // L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWlj
// SIG // cm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAo
// SIG // MSkuY3JsMGwGCCsGAQUFBwEBBGAwXjBcBggrBgEFBQcw
// SIG // AoZQaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9w
// SIG // cy9jZXJ0cy9NaWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIw
// SIG // UENBJTIwMjAxMCgxKS5jcnQwDAYDVR0TAQH/BAIwADAT
// SIG // BgNVHSUEDDAKBggrBgEFBQcDCDANBgkqhkiG9w0BAQsF
// SIG // AAOCAgEAykuUgTc1KMszMgsHbhgjgEGv/dCHFf0by99C
// SIG // 45SR770/udCNNeqlT610Ehz13xGFU6Hci+TLUPUnhvUn
// SIG // Suz7xkiWRru5RjZZmSonEVv8npa3z1QveUfngtyi0Jd6
// SIG // qlSykoEVJ6tDuR1Kw9xU9yvthZWhQs/ymyOwh+mxt0C9
// SIG // wbeLJ92er2vc9ly12pFxbCNDJ+mQ7v520hAvreWqZ02G
// SIG // OJhw0R4c1iP39iNBzHOoz+DsO0sYjwhaz9HrvYMEzOD1
// SIG // MJdLPWfUFsZ//iTd3jzEykk02WjnZNzIe2ENfmQ/KblG
// SIG // XHeSe8JYqimTFxl5keMfLUELjAh0mhQ1vLCJZ20BwC4O
// SIG // 57Eg7yO/YuBno+4RrV0CD2gp4BO10KFW2SQ/MhvRWK7H
// SIG // bgS6Bzt70rkIeSUto7pRkHMqrnhubITcXddky6GtZsmw
// SIG // M3hvqXuStMeU1W5NN3HA8ypjPLd/bomfGx96Huw8Orft
// SIG // cQvk7thdNu4JhAyKUXUP7dKMCJfrOdplg0j1tE0aiE+p
// SIG // DTSQVmPzGezCL42slyPJVXpu4xxE0hpACr2ua0LHv/LB
// SIG // 6RV5C4CO4Ms/pfal//F3O+hJZe5ixevzKNkXXbxPOa1R
// SIG // +SIrW/rHZM6RIDLTJxTGFDM1hQDyafGu9S/a7umkvilg
// SIG // BHNxZfk0IYE7RRWJcG7oiY+FGdx1cs0wggdxMIIFWaAD
// SIG // AgECAhMzAAAAFcXna54Cm0mZAAAAAAAVMA0GCSqGSIb3
// SIG // DQEBCwUAMIGIMQswCQYDVQQGEwJVUzETMBEGA1UECBMK
// SIG // V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
// SIG // A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMTIwMAYD
// SIG // VQQDEylNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBB
// SIG // dXRob3JpdHkgMjAxMDAeFw0yMTA5MzAxODIyMjVaFw0z
// SIG // MDA5MzAxODMyMjVaMHwxCzAJBgNVBAYTAlVTMRMwEQYD
// SIG // VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
// SIG // MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
// SIG // JjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBD
// SIG // QSAyMDEwMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIIC
// SIG // CgKCAgEA5OGmTOe0ciELeaLL1yR5vQ7VgtP97pwHB9Kp
// SIG // bE51yMo1V/YBf2xK4OK9uT4XYDP/XE/HZveVU3Fa4n5K
// SIG // Wv64NmeFRiMMtY0Tz3cywBAY6GB9alKDRLemjkZrBxTz
// SIG // xXb1hlDcwUTIcVxRMTegCjhuje3XD9gmU3w5YQJ6xKr9
// SIG // cmmvHaus9ja+NSZk2pg7uhp7M62AW36MEBydUv626GIl
// SIG // 3GoPz130/o5Tz9bshVZN7928jaTjkY+yOSxRnOlwaQ3K
// SIG // Ni1wjjHINSi947SHJMPgyY9+tVSP3PoFVZhtaDuaRr3t
// SIG // pK56KTesy+uDRedGbsoy1cCGMFxPLOJiss254o2I5Jas
// SIG // AUq7vnGpF1tnYN74kpEeHT39IM9zfUGaRnXNxF803RKJ
// SIG // 1v2lIH1+/NmeRd+2ci/bfV+AutuqfjbsNkz2K26oElHo
// SIG // vwUDo9Fzpk03dJQcNIIP8BDyt0cY7afomXw/TNuvXsLz
// SIG // 1dhzPUNOwTM5TI4CvEJoLhDqhFFG4tG9ahhaYQFzymei
// SIG // XtcodgLiMxhy16cg8ML6EgrXY28MyTZki1ugpoMhXV8w
// SIG // dJGUlNi5UPkLiWHzNgY1GIRH29wb0f2y1BzFa/ZcUlFd
// SIG // Etsluq9QBXpsxREdcu+N+VLEhReTwDwV2xo3xwgVGD94
// SIG // q0W29R6HXtqPnhZyacaue7e3PmriLq0CAwEAAaOCAd0w
// SIG // ggHZMBIGCSsGAQQBgjcVAQQFAgMBAAEwIwYJKwYBBAGC
// SIG // NxUCBBYEFCqnUv5kxJq+gpE8RjUpzxD/LwTuMB0GA1Ud
// SIG // DgQWBBSfpxVdAF5iXYP05dJlpxtTNRnpcjBcBgNVHSAE
// SIG // VTBTMFEGDCsGAQQBgjdMg30BATBBMD8GCCsGAQUFBwIB
// SIG // FjNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3Bz
// SIG // L0RvY3MvUmVwb3NpdG9yeS5odG0wEwYDVR0lBAwwCgYI
// SIG // KwYBBQUHAwgwGQYJKwYBBAGCNxQCBAweCgBTAHUAYgBD
// SIG // AEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQFMAMBAf8w
// SIG // HwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9lJBb186aGMQw
// SIG // VgYDVR0fBE8wTTBLoEmgR4ZFaHR0cDovL2NybC5taWNy
// SIG // b3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvTWljUm9v
// SIG // Q2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoGCCsGAQUFBwEB
// SIG // BE4wTDBKBggrBgEFBQcwAoY+aHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29DZXJBdXRf
// SIG // MjAxMC0wNi0yMy5jcnQwDQYJKoZIhvcNAQELBQADggIB
// SIG // AJ1VffwqreEsH2cBMSRb4Z5yS/ypb+pcFLY+TkdkeLEG
// SIG // k5c9MTO1OdfCcTY/2mRsfNB1OW27DzHkwo/7bNGhlBgi
// SIG // 7ulmZzpTTd2YurYeeNg2LpypglYAA7AFvonoaeC6Ce57
// SIG // 32pvvinLbtg/SHUB2RjebYIM9W0jVOR4U3UkV7ndn/OO
// SIG // PcbzaN9l9qRWqveVtihVJ9AkvUCgvxm2EhIRXT0n4ECW
// SIG // OKz3+SmJw7wXsFSFQrP8DJ6LGYnn8AtqgcKBGUIZUnWK
// SIG // NsIdw2FzLixre24/LAl4FOmRsqlb30mjdAy87JGA0j3m
// SIG // Sj5mO0+7hvoyGtmW9I/2kQH2zsZ0/fZMcm8Qq3UwxTSw
// SIG // ethQ/gpY3UA8x1RtnWN0SCyxTkctwRQEcb9k+SS+c23K
// SIG // jgm9swFXSVRk2XPXfx5bRAGOWhmRaw2fpCjcZxkoJLo4
// SIG // S5pu+yFUa2pFEUep8beuyOiJXk+d0tBMdrVXVAmxaQFE
// SIG // fnyhYWxz/gq77EFmPWn9y8FBSX5+k77L+DvktxW/tM4+
// SIG // pTFRhLy/AsGConsXHRWJjXD+57XQKBqJC4822rpM+Zv/
// SIG // Cuk0+CQ1ZyvgDbjmjJnW4SLq8CdCPSWU5nR0W2rRnj7t
// SIG // fqAxM328y+l7vzhwRNGQ8cirOoo6CGJ/2XBjU02N7oJt
// SIG // pQUQwXEGahC0HVUzWLOhcGbyoYIC0jCCAjsCAQEwgfyh
// SIG // gdSkgdEwgc4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpX
// SIG // YXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYD
// SIG // VQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKTAnBgNV
// SIG // BAsTIE1pY3Jvc29mdCBPcGVyYXRpb25zIFB1ZXJ0byBS
// SIG // aWNvMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVTTjo4OTdB
// SIG // LUUzNTYtMTcwMTElMCMGA1UEAxMcTWljcm9zb2Z0IFRp
// SIG // bWUtU3RhbXAgU2VydmljZaIjCgEBMAcGBSsOAwIaAxUA
// SIG // W6h6/24WCo7WZz6CEVAeLztcmD6ggYMwgYCkfjB8MQsw
// SIG // CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
// SIG // MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
// SIG // b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3Nv
// SIG // ZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDANBgkqhkiG9w0B
// SIG // AQUFAAIFAOcvc+8wIhgPMjAyMjExMjgyMTUyNDdaGA8y
// SIG // MDIyMTEyOTIxNTI0N1owdzA9BgorBgEEAYRZCgQBMS8w
// SIG // LTAKAgUA5y9z7wIBADAKAgEAAgILEwIB/zAHAgEAAgIR
// SIG // RjAKAgUA5zDFbwIBADA2BgorBgEEAYRZCgQCMSgwJjAM
// SIG // BgorBgEEAYRZCgMCoAowCAIBAAIDB6EgoQowCAIBAAID
// SIG // AYagMA0GCSqGSIb3DQEBBQUAA4GBAJ/Vrg0CGlXoMFG3
// SIG // gPXLaFFJrCiQWQZoCdLYsjkU9TQSrbnu+7Vp6Iac5olM
// SIG // lAE2/iL+owRdK4ISDHNGcJAbKG2Vuz2nxItb6jLJrWy8
// SIG // u2WxnzNSPBSxLaJshj53uQPMTA++o/UL62fHcgMjlFGl
// SIG // 9NxJY9pKYZmsOuwJG5LWTuJJMYIEDTCCBAkCAQEwgZMw
// SIG // fDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWlj
// SIG // cm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAGr
// SIG // CQnvq2PU6KkAAQAAAaswDQYJYIZIAWUDBAIBBQCgggFK
// SIG // MBoGCSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAvBgkq
// SIG // hkiG9w0BCQQxIgQgrfcnuGZaxi2P2lq4sndxQjoOejM8
// SIG // 2zpGFF9PFZipOIswgfoGCyqGSIb3DQEJEAIvMYHqMIHn
// SIG // MIHkMIG9BCAOHK/6sIVgEVSVD3Arvk6OyQKvRxFHKyra
// SIG // UzbN1/AKVzCBmDCBgKR+MHwxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFBDQSAyMDEwAhMzAAABqwkJ76tj1OipAAEAAAGrMCIE
// SIG // ILArDCcJ8Y9bpyKVLIs/GRDE6URzBw/PxEJivAeqhKNq
// SIG // MA0GCSqGSIb3DQEBCwUABIICAJ78aiH4OZKBWnuc+sHp
// SIG // ta1l10FF2rufLPu2iTokSTRF9WV9SYWlEvomDzqJ3v2v
// SIG // 8b/FmdT1HeYW2yuSSeX4P7EugcrGh516Y1mnVWv3dUhX
// SIG // GYPK8NczCpQ6KaH8Yd5xtQGnNB+PDqbzQRVgLnWzjN3I
// SIG // 8LoPo2bP1t2V0eFX+O9Vx/xfUEKgQOUmiZbGPGwSIMUR
// SIG // hPRBa5dBPLqNj41Mk6PbLs+++fx5JRjPd0MerSDWnxLn
// SIG // uJeu79TJVWp72pyKI39IwyET9xhruHOA39SYJKEkyl6c
// SIG // 8GBeEbQmCYQJIIhvGlyi4kvnm06LoimxOykKCEimls7b
// SIG // VxpH+AaKOQItGYbijF85ZQ90IJfloEDWTYsVjE1Ro8U2
// SIG // l7fPMN9/5nbIU+94vf2A1Kp7S4BHUxPOEj2pUtXKcjnr
// SIG // K0S+vYzYWFKKgMIb9wbx4mblr9E4quZgIfIM0z1tkCEp
// SIG // GP5SBJ3lJAQhYRt+EHfzUnj9ltCX7KHlgi6hBF30hzdE
// SIG // e5U+INSy8C/rpEwPUFGqW7XCT7Nh1Bb0LjONDXeWMBt7
// SIG // HLmBcJJbyoLLXdrzNV8EWMGJ39SFufD1PRnKEjRjysCY
// SIG // e7fKuVwxy0K+VTLkhJc/gmoJP5y2mrrCZhQCKmmR//pK
// SIG // +jOdCUU4Y6Xst8WGU+/IgNlwEdTteS1d6SB3CgyoJJxY
// SIG // Mt81
// SIG // End signature block
