// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIolwYJKoZIhvcNAQcCoIIoiDCCKIQCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg3wMIIGbjCCBFagAwIBAgITMwAAAwVNYg1ohQeqMwAA
// SIG // AAADBTANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIyMDgwNDIwMjM1N1oX
// SIG // DTIzMDgwMzIwMjM1N1owYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBALgT1J98uPoa1weiQsnOFH3y
// SIG // L9VcrQ5JLGIZT50ZFJp4cOpQ+gHtRxxVE89hPiTPzLAR
// SIG // VHaubXNodZsBmWk4PbWNkPwm0aKis02uN71Farp9Ouc5
// SIG // 0Pzn1DT+R3+e3ahXLhtC5mlTaCZiJ4AU3blyaqQLKLeJ
// SIG // a3pqyHBnJiXySNBrhLBkleguDLiqBLaziCWbQLAIlLUl
// SIG // ypI/cutECrDKU4/f7PHM+1gUQdK+WZnH/+t82oAY0VXG
// SIG // 3pUMZzv3UysNO4CS1aFAjQG5cjdJuS812n658mOSIPwF
// SIG // 5zmfaIH14qh/XPyfi0a6WdZaZIRth3dnP9VcGN1sDSuc
// SIG // RV/no9+aSPqWyt19ipN4jiuJILUHhm+3eekt2KGaKWys
// SIG // 2whswE1RkBoAq7GmvFIrXvcEB0mqM/09bIfgvkjN50z/
// SIG // 5XmMlyrqtmD0Fe+V1DTbfOyhdBZpt4G2cbqK3eoFUoJI
// SIG // ytn3N06zIBT0kd8BVWDWKOTi0VHsXx8cvHDKDLOL5iK2
// SIG // REcibwIDAQABo4IBfjCCAXowHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFMPGGeTy
// SIG // z3Y+F0AQcJOKcmziq1YbMFAGA1UdEQRJMEekRTBDMSkw
// SIG // JwYDVQQLEyBNaWNyb3NvZnQgT3BlcmF0aW9ucyBQdWVy
// SIG // dG8gUmljbzEWMBQGA1UEBRMNNDY0MjIzKzQ3MjIzNzAf
// SIG // BgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBU
// SIG // BgNVHR8ETTBLMEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jv
// SIG // c29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUw
// SIG // UzBRBggrBgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3Nv
// SIG // ZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAw
// SIG // DQYJKoZIhvcNAQEMBQADggIBAGhKSnmsyGvycL6Dw4uq
// SIG // 3wDtwdM/hSbG6b5NqxUtIoE9TMT4Uqj+NWtYfrB09uq8
// SIG // OzxkLHnaEec19x5EyVxy+DBpbmzNU3/469qF4kyp0FNj
// SIG // CJlmFgFoxLNFzisxKeTXw1pFppM5AxHG+/VqIdQlOCbc
// SIG // 2nTSJLqxag4G3J+fsEE6uywxw6NxfieRBzAJd2HGPLUV
// SIG // pt87GLklNjsyxDUJYkxFtgkj1khGqwIG6ZNkbIXPsxR8
// SIG // S9oiKqAP71cZEwN6+TnnPIotqXeBsC+urL/NB8NWxBEe
// SIG // npVFFF4zNXd3sbmb4H/668DKQaIP5Qm0Ige2nmxgXAPq
// SIG // 9CPYZawXOvxOhOFgiU3AtLFAK/Oc+sgkXCeLX2A6RKq8
// SIG // SqgwHwtjWXaviyEToDFwSMdel+y+9wSZokXBwr+7TjGL
// SIG // uRinndUGjiVtJU/rsz/y9xC5TiOn6BAjwXB0EktoM0dP
// SIG // cTu3d9AC0q2gylEwTPAdfSbpABG+IPHEgtOoDxSBxUGc
// SIG // hdEElyklcwz6C8oGSXR6CVGHV7QW+cH03C9DH7nBBhAh
// SIG // UIojqCYwKb9b8Gam25brrUFwf8to5dXLZ14HYeRA9c6A
// SIG // H2CBwiE4ABPpOq/iypGWil8Vyg3Uf6LmgAEMMxZYLtNg
// SIG // 5GbM3tcTW2M3C0EZFIpiuT43hvm8uNHpXAZP3PJ3yCc5
// SIG // yR09MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkq
// SIG // hkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEy
// SIG // MDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNh
// SIG // dGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5
// SIG // WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWdu
// SIG // aW5nIFBDQSAyMDExMIICIjANBgkqhkiG9w0BAQEFAAOC
// SIG // Ag8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGf
// SIG // Qhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDI
// SIG // OdUBFDFC04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv
// SIG // 2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13Y
// SIG // xC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT
// SIG // +OPeBw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy
// SIG // 4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
// SIG // kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
// SIG // OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVf
// SIG // GCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmdX4ji
// SIG // JV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bys
// SIG // AoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLn
// SIG // JN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zdsGbiwZeB
// SIG // e+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx
// SIG // 7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwT
// SIG // XWCVmj5PM4TasIgX3p5O9JawvEagbJjS4NaIjAsCAwEA
// SIG // AaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1Ud
// SIG // DgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEE
// SIG // AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYw
// SIG // DwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToC
// SIG // MZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBL
// SIG // hklodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
// SIG // bC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
// SIG // MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
// SIG // BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNf
// SIG // MjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcu
// SIG // AzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1hcnljcHMu
// SIG // aHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABf
// SIG // AHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQA
// SIG // LiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn8oalmOBUeRou
// SIG // 09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+
// SIG // vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzS
// SIG // Gksc8zxCi1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlE
// SIG // PXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6V
// SIG // oCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu
// SIG // 5a8n7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560
// SIG // STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
// SIG // mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
// SIG // bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HN
// SIG // pZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYbBL7f
// SIG // QccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AA
// SIG // KcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3
// SIG // S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sLgOppO6/8
// SIG // MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7
// SIG // qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJ
// SIG // UnMTDXpQzTGCGf8wghn7AgEBMIGVMH4xCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2Rl
// SIG // IFNpZ25pbmcgUENBIDIwMTECEzMAAAMFTWINaIUHqjMA
// SIG // AAAAAwUwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcN
// SIG // AQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
// SIG // MAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIKTQ
// SIG // ts56jQmXdTOrJhxHePDRP6IYHMqtdIFdJu6K2KWDMEIG
// SIG // CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBv
// SIG // AGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20w
// SIG // DQYJKoZIhvcNAQEBBQAEggGAQQwHtLKIyVtgWoCqVsWv
// SIG // 4Bb/1jXrDx1cHMgtLhO2IfCl0IAt225VJnBz9khi4eks
// SIG // 4joPvjDAR3hxDVNE5r18kXquLb04I8x2MltCubELdP5h
// SIG // G6ChD3Zg9GNhhKeZXxb17ummzGwqAGspqvLBgJt0wfSK
// SIG // DZXhSZbohjel3cicJzpD0LrdH5D5I1IL10LEfVdKTNUL
// SIG // B9VKBAuX0bVgRWNJbIYV3XpKgPim8e+sBhPiWPBQrGah
// SIG // RTmhdcme8S69gx41RJZD8RbfxMiCCOuEHXqpeC4nprO2
// SIG // x9lNgdCdKvlWES5/NSNKmkCdZnLIUYLmaf1ThSSxUv12
// SIG // xqKxtdO7kYZ/ZgYb56+fAyboXdqEHBh+7z8SVtfP8xDh
// SIG // KtQB5QlT0Yig4/JqfEvQ7fs5PYs90PaqYpTGPR+iUwEd
// SIG // M2xnnpfLw9MERMA4Pk/GHSYGzHcBn2QNs3tbOtiTu9cS
// SIG // PJx4nVrPEP038J3UikE4U7WbegtWcva1nmoLSaWgKV2h
// SIG // bBA73iB4oYIXCTCCFwUGCisGAQQBgjcDAwExghb1MIIW
// SIG // 8QYJKoZIhvcNAQcCoIIW4jCCFt4CAQMxDzANBglghkgB
// SIG // ZQMEAgEFADCCAVUGCyqGSIb3DQEJEAEEoIIBRASCAUAw
// SIG // ggE8AgEBBgorBgEEAYRZCgMBMDEwDQYJYIZIAWUDBAIB
// SIG // BQAEIB+G11lKVwuucvxaFPbi9NMrkUnSKOjiMh1IwcjN
// SIG // 8A6xAgZjc/KVDF4YEzIwMjIxMTI5MDU0MjU0LjU3OVow
// SIG // BIACAfSggdSkgdEwgc4xCzAJBgNVBAYTAlVTMRMwEQYD
// SIG // VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
// SIG // MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
// SIG // KTAnBgNVBAsTIE1pY3Jvc29mdCBPcGVyYXRpb25zIFB1
// SIG // ZXJ0byBSaWNvMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVT
// SIG // TjpGODdBLUUzNzQtRDdCOTElMCMGA1UEAxMcTWljcm9z
// SIG // b2Z0IFRpbWUtU3RhbXAgU2VydmljZaCCEVwwggcQMIIE
// SIG // +KADAgECAhMzAAABrqoLXLM0pZUaAAEAAAGuMA0GCSqG
// SIG // SIb3DQEBCwUAMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
// SIG // EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
// SIG // HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAk
// SIG // BgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAy
// SIG // MDEwMB4XDTIyMDMwMjE4NTEzN1oXDTIzMDUxMTE4NTEz
// SIG // N1owgc4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
// SIG // aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
// SIG // ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKTAnBgNVBAsT
// SIG // IE1pY3Jvc29mdCBPcGVyYXRpb25zIFB1ZXJ0byBSaWNv
// SIG // MSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVTTjpGODdBLUUz
// SIG // NzQtRDdCOTElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUt
// SIG // U3RhbXAgU2VydmljZTCCAiIwDQYJKoZIhvcNAQEBBQAD
// SIG // ggIPADCCAgoCggIBAJOMGvEhNQwLHactznPpY8Jg5qI8
// SIG // Qsgp0mhl2G2ztVPonq4gsOMe5u9p5f17PIM1KXjUaKNl
// SIG // 3djncq29LiqmqnaKORggPHNEk7Q+tal5Iyc+S8k/R31g
// SIG // CGt4qvQVqBLQNivxOukUfapG41LTdLHeM4uwInk+QrGQ
// SIG // H2K4wjNtiUpirF2PdCcbkXyALEpyT2RrwzJmzcmbdCsc
// SIG // Y0N3RHxrMeWQ3k7sNt41NBZOT+4pCmkw8UkgKiSJXMzK
// SIG // s38MxUqx/OlS80dLDTHd+Zei1S1/qbCtTGzNm0bj6qfk
// SIG // lUM3JFAF1JLXwwvqgZRdDQU6224wtGnwalTaOI0R0eX+
// SIG // crcPpXGB27EIgYU+0lo2aH79SNrsPWEcdBICd0yfhFU2
// SIG // niVJepGzkXetJvbFxW3iN7scjLfw/S6UXF7wtEzdONXV
// SIG // iI5P2UM779P6EIZ+g81E2MWX8XjLVyvIsvzyckJ4FFi+
// SIG // h1yPE+vzckPxzHOsiLaafucsyMjAaAM8Wwa+02BujEOy
// SIG // lfLSyk0iv9IvSI9ZkJW/gLvQ42U0+U035ZhUhCqbKEWE
// SIG // MIr2ya2rYprUMEKcXf4R97LVPBfsJnbkNUubpUA4K1i7
// SIG // ijQ1pkUlt+YQ/34mtEy7eSigVpVznqfrNVerCvHG5Iwf
// SIG // eFVhPNbAwK6lBEQ29nMYjRXj4QLyvmKRmqOJM/w1AgMB
// SIG // AAGjggE2MIIBMjAdBgNVHQ4EFgQU0zBv378oYIrBqa10
// SIG // /vztZDphUe4wHwYDVR0jBBgwFoAUn6cVXQBeYl2D9OXS
// SIG // ZacbUzUZ6XIwXwYDVR0fBFgwVjBUoFKgUIZOaHR0cDov
// SIG // L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWlj
// SIG // cm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAo
// SIG // MSkuY3JsMGwGCCsGAQUFBwEBBGAwXjBcBggrBgEFBQcw
// SIG // AoZQaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9w
// SIG // cy9jZXJ0cy9NaWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIw
// SIG // UENBJTIwMjAxMCgxKS5jcnQwDAYDVR0TAQH/BAIwADAT
// SIG // BgNVHSUEDDAKBggrBgEFBQcDCDANBgkqhkiG9w0BAQsF
// SIG // AAOCAgEAXb+R8P1VAEQOPK0zAxADIXP4cJQmartjVFLM
// SIG // EkLYh39PFtVbt84Rv0Q1GSTYmhP8f/OOvnmC5ejw3Nc1
// SIG // VRi74rWGUITv18Wqr8eBvASd4eDAxFbA8knOOm/ZySkM
// SIG // DDYdb6738aQ0yvqf7AWchgPntCc/nhNapSJmjzUke7Ev
// SIG // jB8ei0BnY0xl+AQcSxJG/Vnsm9IwOer8E1miVLYfPn9f
// SIG // IDdaav1bq9i+gnZf1hS7apGpxbitCJr1KGD4jIyABkxH
// SIG // heoPOhhtQm1uznE7blKxH8pU7W2A+eqggsNkM3VB0nrz
// SIG // RZBqm4SmBSNhOPzy3ofOmLcRK/aloOAr6nehi8i5lhmT
// SIG // g1LkOAxChLwHvluiCY9K+2vIpt48ioK/h+tz5RgVdb+S
// SIG // 8xwn728lN8KPkkB2Ra5iicrvtgA55wSUdh6FFxXxeS+b
// SIG // sgBayn7ZyafTpDM7BQOBYwaodsuVf5XgGryGx84k4R58
// SIG // mPwB3Q09CRAGs35NOt6TrPXqcylNu6Zz8xTQDcaJp54p
// SIG // KyOoW5iIDFjpLneXTEjtWCFCgAo4zbp9CNITp97KPnc3
// SIG // gZVaMvEpU8Sp7VZwN9ckR2WDKyOjDghIcfuFJTLOdkOu
// SIG // MLGsWPdnY6idtWc2bUDQa2QbzmNSZyFthEprwQ2GmgaG
// SIG // bGKuYVVqUj/Yt21HD0PBeDI5Mal8ScwwggdxMIIFWaAD
// SIG // AgECAhMzAAAAFcXna54Cm0mZAAAAAAAVMA0GCSqGSIb3
// SIG // DQEBCwUAMIGIMQswCQYDVQQGEwJVUzETMBEGA1UECBMK
// SIG // V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
// SIG // A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMTIwMAYD
// SIG // VQQDEylNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBB
// SIG // dXRob3JpdHkgMjAxMDAeFw0yMTA5MzAxODIyMjVaFw0z
// SIG // MDA5MzAxODMyMjVaMHwxCzAJBgNVBAYTAlVTMRMwEQYD
// SIG // VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
// SIG // MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
// SIG // JjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBD
// SIG // QSAyMDEwMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIIC
// SIG // CgKCAgEA5OGmTOe0ciELeaLL1yR5vQ7VgtP97pwHB9Kp
// SIG // bE51yMo1V/YBf2xK4OK9uT4XYDP/XE/HZveVU3Fa4n5K
// SIG // Wv64NmeFRiMMtY0Tz3cywBAY6GB9alKDRLemjkZrBxTz
// SIG // xXb1hlDcwUTIcVxRMTegCjhuje3XD9gmU3w5YQJ6xKr9
// SIG // cmmvHaus9ja+NSZk2pg7uhp7M62AW36MEBydUv626GIl
// SIG // 3GoPz130/o5Tz9bshVZN7928jaTjkY+yOSxRnOlwaQ3K
// SIG // Ni1wjjHINSi947SHJMPgyY9+tVSP3PoFVZhtaDuaRr3t
// SIG // pK56KTesy+uDRedGbsoy1cCGMFxPLOJiss254o2I5Jas
// SIG // AUq7vnGpF1tnYN74kpEeHT39IM9zfUGaRnXNxF803RKJ
// SIG // 1v2lIH1+/NmeRd+2ci/bfV+AutuqfjbsNkz2K26oElHo
// SIG // vwUDo9Fzpk03dJQcNIIP8BDyt0cY7afomXw/TNuvXsLz
// SIG // 1dhzPUNOwTM5TI4CvEJoLhDqhFFG4tG9ahhaYQFzymei
// SIG // XtcodgLiMxhy16cg8ML6EgrXY28MyTZki1ugpoMhXV8w
// SIG // dJGUlNi5UPkLiWHzNgY1GIRH29wb0f2y1BzFa/ZcUlFd
// SIG // Etsluq9QBXpsxREdcu+N+VLEhReTwDwV2xo3xwgVGD94
// SIG // q0W29R6HXtqPnhZyacaue7e3PmriLq0CAwEAAaOCAd0w
// SIG // ggHZMBIGCSsGAQQBgjcVAQQFAgMBAAEwIwYJKwYBBAGC
// SIG // NxUCBBYEFCqnUv5kxJq+gpE8RjUpzxD/LwTuMB0GA1Ud
// SIG // DgQWBBSfpxVdAF5iXYP05dJlpxtTNRnpcjBcBgNVHSAE
// SIG // VTBTMFEGDCsGAQQBgjdMg30BATBBMD8GCCsGAQUFBwIB
// SIG // FjNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3Bz
// SIG // L0RvY3MvUmVwb3NpdG9yeS5odG0wEwYDVR0lBAwwCgYI
// SIG // KwYBBQUHAwgwGQYJKwYBBAGCNxQCBAweCgBTAHUAYgBD
// SIG // AEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQFMAMBAf8w
// SIG // HwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9lJBb186aGMQw
// SIG // VgYDVR0fBE8wTTBLoEmgR4ZFaHR0cDovL2NybC5taWNy
// SIG // b3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvTWljUm9v
// SIG // Q2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoGCCsGAQUFBwEB
// SIG // BE4wTDBKBggrBgEFBQcwAoY+aHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29DZXJBdXRf
// SIG // MjAxMC0wNi0yMy5jcnQwDQYJKoZIhvcNAQELBQADggIB
// SIG // AJ1VffwqreEsH2cBMSRb4Z5yS/ypb+pcFLY+TkdkeLEG
// SIG // k5c9MTO1OdfCcTY/2mRsfNB1OW27DzHkwo/7bNGhlBgi
// SIG // 7ulmZzpTTd2YurYeeNg2LpypglYAA7AFvonoaeC6Ce57
// SIG // 32pvvinLbtg/SHUB2RjebYIM9W0jVOR4U3UkV7ndn/OO
// SIG // PcbzaN9l9qRWqveVtihVJ9AkvUCgvxm2EhIRXT0n4ECW
// SIG // OKz3+SmJw7wXsFSFQrP8DJ6LGYnn8AtqgcKBGUIZUnWK
// SIG // NsIdw2FzLixre24/LAl4FOmRsqlb30mjdAy87JGA0j3m
// SIG // Sj5mO0+7hvoyGtmW9I/2kQH2zsZ0/fZMcm8Qq3UwxTSw
// SIG // ethQ/gpY3UA8x1RtnWN0SCyxTkctwRQEcb9k+SS+c23K
// SIG // jgm9swFXSVRk2XPXfx5bRAGOWhmRaw2fpCjcZxkoJLo4
// SIG // S5pu+yFUa2pFEUep8beuyOiJXk+d0tBMdrVXVAmxaQFE
// SIG // fnyhYWxz/gq77EFmPWn9y8FBSX5+k77L+DvktxW/tM4+
// SIG // pTFRhLy/AsGConsXHRWJjXD+57XQKBqJC4822rpM+Zv/
// SIG // Cuk0+CQ1ZyvgDbjmjJnW4SLq8CdCPSWU5nR0W2rRnj7t
// SIG // fqAxM328y+l7vzhwRNGQ8cirOoo6CGJ/2XBjU02N7oJt
// SIG // pQUQwXEGahC0HVUzWLOhcGbyoYICzzCCAjgCAQEwgfyh
// SIG // gdSkgdEwgc4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpX
// SIG // YXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYD
// SIG // VQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKTAnBgNV
// SIG // BAsTIE1pY3Jvc29mdCBPcGVyYXRpb25zIFB1ZXJ0byBS
// SIG // aWNvMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVTTjpGODdB
// SIG // LUUzNzQtRDdCOTElMCMGA1UEAxMcTWljcm9zb2Z0IFRp
// SIG // bWUtU3RhbXAgU2VydmljZaIjCgEBMAcGBSsOAwIaAxUA
// SIG // vJqwk/xnycgV5Gdy5b4IwE/TWuOggYMwgYCkfjB8MQsw
// SIG // CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
// SIG // MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
// SIG // b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3Nv
// SIG // ZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDANBgkqhkiG9w0B
// SIG // AQUFAAIFAOcvlE8wIhgPMjAyMjExMjkwMDEwNTVaGA8y
// SIG // MDIyMTEzMDAwMTA1NVowdDA6BgorBgEEAYRZCgQBMSww
// SIG // KjAKAgUA5y+UTwIBADAHAgEAAgIexTAHAgEAAgIROjAK
// SIG // AgUA5zDlzwIBADA2BgorBgEEAYRZCgQCMSgwJjAMBgor
// SIG // BgEEAYRZCgMCoAowCAIBAAIDB6EgoQowCAIBAAIDAYag
// SIG // MA0GCSqGSIb3DQEBBQUAA4GBAId2guZAvWypfxxPNB0f
// SIG // 7eBwxgc3yrL73E1j02oLU6zMAIB4ZTyG+EU8hHw8aIqo
// SIG // YP7Upssufv3B3e25bdTPMBGyWE4QhDtvb3sOYKPMJhcR
// SIG // e/eMvaStKC3wakKzJPhaIhoYXRExiLIynSuz/eSaczyo
// SIG // 7M2iEEMWM8bN/4co0+PtMYIEDTCCBAkCAQEwgZMwfDEL
// SIG // MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
// SIG // EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
// SIG // c29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9z
// SIG // b2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAGuqgtc
// SIG // szSllRoAAQAAAa4wDQYJYIZIAWUDBAIBBQCgggFKMBoG
// SIG // CSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAvBgkqhkiG
// SIG // 9w0BCQQxIgQgSkIbo5joLTRxmKNDo/WFewo9i5xfvEkX
// SIG // OaTyOt3j2W0wgfoGCyqGSIb3DQEJEAIvMYHqMIHnMIHk
// SIG // MIG9BCBJKB0+uIzDWqHun09mqTU8uOg6tew0yu1uQ0iU
// SIG // /FJvaDCBmDCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYD
// SIG // VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
// SIG // MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
// SIG // JjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBD
// SIG // QSAyMDEwAhMzAAABrqoLXLM0pZUaAAEAAAGuMCIEIOYQ
// SIG // 6N+RcqoDsUUrWGj6NAIFo8wICZBgGqyZMF1zFYTAMA0G
// SIG // CSqGSIb3DQEBCwUABIICACJaKJVnZMLr6ERfYnEzG/8v
// SIG // s7dUBCNRb9+vsXFcq2Lurjd8b5RY+fl+k2lRN/f3Rr64
// SIG // gKsa2pKwKbGPHL5ZoBHqFFDh75kbsP52XIuDXSLaPZFV
// SIG // TGuACP9rCQlhP+fO0qkOZpLjP8pPAMaru7EePNqJ5HEP
// SIG // wqS3Jh7sZtPOBJFOLyGU3384MzHOd7qBd0dLlMpuZfqZ
// SIG // FW5AdUzbbWdcKSHDsHW9uKrGMKH6bslHblk1hpLsHjgt
// SIG // snfD9LmMj6i4VIbXqrOzcjnV6DHlk0zBYRx5MX9QHa4l
// SIG // aQp6ParMCeSM5VgWBw3sDBG3FA+D3K5dXgLIPv+lJ3IL
// SIG // DvmTn+WmeDWDvqpdAQJKM9+JljxdRiVzsRVXTMQLGG/U
// SIG // DFcOS675hoYLMThPK+p2PVFb1kSj/nWdT+tKlVg/+PIp
// SIG // 5RtLW/AxYmN0HJXEAUcMBsn4OkUADA8mwTyvdi2ObC7q
// SIG // GQMNU5mNTMr+Y7GN431MHe2fLHDSpjnSE/giWf7BkRKY
// SIG // tEDCuuILtDVyrf2MU7uv6DxHLaWrwf/lSsXe/vTSVWlH
// SIG // y2IgPwVtaUglj9dJQdbCI16OAZQEbocCnJm9BNTMXJ9S
// SIG // So9M5u9H1ttQK7C+HEApmFX1YuDncFRaRZqUsXkkfpvU
// SIG // zhIhvHusib7FbqcXgpO9Xj4KI9Fq0yRb0KWxUywNdu09
// SIG // End signature block
